@@ -20,20 +20,6 @@
 #'
 #' The package reads mass spectrometry data in mzXML format. \cr
 #'
-#' \tabular{ll}{
-#'
-#'  Package: \tab readMzXmlData\cr
-#'
-#'  Type: \tab Package\cr
-#'
-#'  Version: \tab 2.8.1\cr
-#'
-#'  Date: \tab 2015-09-16\cr
-#'
-#'  License: \tab GPL(version 3 or later)\cr
-#'
-#' }
-#'
 #' Main functions:
 #'
 #' \code{\link{readMzXmlFile}}: Reads mass spectrometry data in mzXML format.
@@ -44,7 +30,6 @@
 #' \code{\link{mqReadMzXml}}: Reads mass spectrometry data into MALDIquant.
 #'
 #' @name readMzXmlData-package
-#' @docType package
 #' @author Sebastian Gibb \email{mail@@sebastiangibb.de}
 #' @seealso \code{\link{readMzXmlDir}}, \code{\link{readMzXmlFile}}
 #' @references See website: \url{https://strimmerlab.github.io/software/maldiquant/}
@@ -54,7 +39,7 @@
 #' @importFrom digest digest
 #' @importFrom utils tail
 #' @importFrom XML xmlEventParse
-NULL
+"_PACKAGE"
 
 #' These functions are defunct and no longer available.
 #'
